extensions [ gis ]

breed
  [trees tree]

breed
  [real-trees real-tree]

breed
  [GISmodel-trees GISmodel-tree]

globals
  [
  year
  mast-period
  gaussian-dist
  short-dispersal-dist
  long-dispersal-dist
  comp-ex-pasture
  comp-shrubs
  seeds-per-tree
  comp-threshold
  height-max
  trees-54
  trees-06
  trees-GIS06
  lulc-54
  DEM
  tree-line
  ]

patches-own
  [
  lulc ; land use or land cover: "forest", "pasture" "ex-pasture"
  elev ; elevation of the centroid of a patch
  succession-stage
  ]

turtles-own
  [
  species ; spruce or larch
  age ; age of trees in years
  height ; tree height
  seed-tree? ;  boolean, is tree mature, i.e. able to produce seeds?
  crown-radius
  ZOI ; radius of the maximum competition influence radius of a tree, depending on tree age
  FON ; sum of assymetric competition influence of neighbouring trees on a tree
  i ;inflection point
  ]

to setup

  ca

  ; set global variables
  set height-max 35
  set year 1954
  set mast-period 7
  set seeds-per-tree 11
  set gaussian-dist 0
  set short-dispersal-dist 15
  set long-dispersal-dist 250
  set comp-ex-pasture 0.32
  set comp-shrubs 0.34
  set comp-threshold 0.7

  if landscape = "Breitlehn" [setup-breitlehn]
  if landscape = "artificial" [setup-artificial]

  reset-ticks

end


to setup-breitlehn

  set lulc-54 gis:load-dataset "/TREELIM data/breitl_lulc54.asc"
  set DEM gis:load-dataset "/TREELIM data/breitl_dem.asc"

  ; set world to gis-data extent
  gis:set-world-envelope
  gis:envelope-of DEM

  ;create DEM
  gis:apply-raster DEM elev

  ;create lulc
  gis:apply-raster lulc-54 lulc
  ask patches with [lulc = 0] ; abandoned
    [
    set lulc "ex-pasture"
    set succession-stage comp-ex-pasture; probability to germinate in an abandoned pasture = 32% (baseline scenario!); 43% (reduced competition scenario)
    ]
  ask patches with [lulc = 1] ; bare ground
    [
    set lulc "bare"
    set succession-stage 0.01; probability to germinate on bare ground = 1%
    ]
  ask patches with [lulc = 2]  ; shrubs
    [
    set lulc "shrubs"
    set succession-stage comp-shrubs; probability to germinate in shrubland = 34% (baseline scenario!); 45% (reduced competition scenario)
    ]
  ask patches with [lulc = 3] ; forest
    [
    set lulc "forest"
    set succession-stage 1.0; probability to germinate in forest = 100% survival
    ]
  ask patches with [lulc = 4] ; pasture
    [
    set lulc "pasture"
    set succession-stage 0.02 ; probability to germinate in a pasture = 2%
    ]

  ; draw selected layer
  choose-layer

  load-trees54
  load-trees06

  if scenario = "baseline" [load-baseline]
  if scenario = "reduced fecundity" [load-red-fec]
  if scenario = "reduced competition" [load-red-comp]
  if scenario = "short distribution" [load-short-dist]

  ;output
  ;export

end



to setup-artificial

  ; set global variables
  set tree-line 250

  ; create DEM
  ask patches
    [
    ; set topography inclined plane, with elevation starting from 1600 and ending at 2600 m a.s.l.
    set elev 1600 + 0.7 * (max-pxcor - pxcor)

    ; create lulc
    ifelse pxcor >= (max-pxcor - tree-line)
      [
      set lulc "forest"
      set succession-stage 1.0; probability to germinate in forest = 100% survival
      ]
      [
      set lulc "ex-pasture"
      set succession-stage comp-ex-pasture; probability to germinate in an abandoned pasture = 32% (baseline scenario!); 43% (reduced competition scenario)
      ]
    ]

  ; draw selected layer
  choose-layer

  ; create trees
  set-default-shape turtles "circle"
  create-trees 1500  ;(max-pycor / 10) * (tree-line / 10) ; define initial number of trees in a forest: initialising with 1 tree per 10m x 10m
    [
    ; create trees at random position within a forest
    setxy (max-pxcor - random-float tree-line) (random-float max-pycor)

    ; height and age: initial values
    set age round (abs 8 * ( random-exponential 3 )) + 1
    set height (35 * (1 - e ^ (-1 * random-normal 0.03 0.003 * age)) ^ 3)

    ; set initial tree variables
    let ran1 random-float 1
    if species-chooser = "spruce only"
      [
      set species "spruce"
      set i 1550 ; inflection point for elevation dependent germination probability
      set color magenta
      ]

    if species-chooser = "10% larch"
      [
      set ran1 random-float 1
      ifelse ran1 > 0.1
        [
        set species "spruce"
        set i 1550 ; inflection point for elevation dependent germination probability
        set color magenta
        ]
        [
        set species "larch"
        set i 1850
        set color orange
        ]
      ]

     if species-chooser = "larch above 1880m"
       [
       ifelse elev < 1880
         [
         set species "spruce"
         set i 1550 ; inflection point for elevation dependent germination probability
         set color magenta
         ]
         [
         set species "larch"
         set i 1850
         set color orange
         ]
       ]

     ifelse height >= 7
       [
       set size 6
       set seed-tree? true
       ]
       [
       set size 2
       set seed-tree? false
       ]
    ]

  ;if scenario = "baseline" [load-baseline]
  ;if scenario = "reduced fec" [load-red-fec]
  ;if scenario = "reduced comp" [load-red-comp]
  ;if scenario = "short dist" [load-short-dist]

  ;output

end




to choose-layer

  ; draw selected layer
  if visible-layer = "lulc" [layer-lulc]
  if visible-layer = "DEM" [layer-DEM]
  if visible-layer = "black" [ask patches [set pcolor black]]

end


; draw DEM layer
to layer-DEM

  ask patches [set pcolor scale-color gray elev 1581 2519]

end


; draw lulc layer
to layer-lulc
  ask patches with [lulc = "ex-pasture"] ; yellow
    [
    set pcolor 47
    ]
  ask patches with [lulc = "bare"] ; grey
    [
    set pcolor 6
    ]
  ask patches with [lulc = "shrubs"]  ; olive green
    [
    set pcolor 37
    ]
  ask patches with [lulc = "forest"] ; forest green
    [
    set pcolor 56
    ]
  ask patches with [lulc = "pasture"] ; intense green
    [
    set pcolor 67
    ]
end


; load tree dataset 1954 from remote sensing data
to load-trees54

  set trees-54 gis:load-dataset "/TREELIM data/trees_1954.shp"

  ; create tree agentset from GIS point data
  set-default-shape trees "circle"
  foreach gis:feature-list-of trees-54
    [
    let current-tree (?1)
    let xy gis:location-of gis:centroid-of current-tree
    let x item 0 xy
    let y item 1 xy

    create-trees 1
      [
      setxy x y
      set age gis:property-value current-tree "AGE"
      set height gis:property-value current-tree "HIGHT1"
      let ran1 random-float 1

      ; set initial tree variables
      if species-chooser = "spruce only"
          [
          set species "spruce"
          set i 1550 ; inflection point for elevation dependent germination probability
          set color magenta
          ]

      if species-chooser = "10% larch"
        [
        set ran1 random-float 1
        ifelse ran1 > 0.1
          [
          set species "spruce"
          set i 1550 ; inflection point for elevation dependent germination probability
          set color magenta
          ]
          [
          set species "larch"
          set i 1850
          set color orange
          ]
        ]

      if species-chooser = "larch above 1880m"
        [
        ifelse elev < 1880
          [
          set species "spruce"
          set i 1550 ; inflection point for elevation dependent germination probability
          set color magenta
          ]
          [
          set species "larch"
          set i 1850
          set color orange
          ]
        ]

        ifelse height >= 7
          [
          set size 6
          set seed-tree? true
          ]
          [
          set size 2
          set seed-tree? false
          ]
      ]
    ]
end



; load trees 06
to load-trees06

  set trees-06 gis:load-dataset "/TREELIM data/trees_06.shp"

  ;create tree 2006 agentset from GIS point data
  ;set-default-shape real-trees "circle"
  foreach gis:feature-list-of trees-06
    [
    let current-tree (?1)
    ;output-print current-tree
    let xy gis:location-of gis:centroid-of current-tree
    ;output-print xy
    let x item 0 xy
    let y item 1 xy
    create-real-trees 1
      [
      setxy x y
      set height gis:property-value current-tree "HIGH_T1"
      set age gis:property-value current-tree "AGE"
      ifelse height >= 7
        [
        ;set color 94 ; light blue
        ;set size 6
        hide-turtle
        set seed-tree? true
        ]
        [
        ;set color 94 ; light blue
        ;set size 2
        hide-turtle
        set seed-tree? false
        ]
      ]
    ]
end


; load baseline scenario
to load-baseline

  set trees-GIS06 gis:load-dataset "/TREELIM data/baserun.shp"

  ;create tree 2006 agentset from GIS point data
  ;set-default-shape real-trees "circle"

  foreach gis:feature-list-of trees-GIS06
    [
    let current-tree (?1)
    ;output-print current-tree
    let xy gis:location-of gis:centroid-of current-tree
    ;output-print xy
    let x item 0 xy
    let y item 1 xy
    create-GISmodel-trees 1
      [
      setxy x y
      set height gis:property-value current-tree "HIGH_T53"
      set age gis:property-value current-tree "AGE"
      ifelse height >= 7
        [
        ;set color green
        ;set size 6
        hide-turtle
        set seed-tree? true
        ]
        [
        ;set color green
        ;set size 2
        hide-turtle
        set seed-tree? false
        ]
      ]
    ]
end



; load reduced competition scenario
to load-red-comp

  set trees-GIS06 gis:load-dataset "/TREELIM data/redcomp.shp"
  set comp-ex-pasture 0.43
  set comp-shrubs 0.45

  ;create tree 2006 agentset from GIS point data
  ;set-default-shape real-trees "circle"

  foreach gis:feature-list-of trees-GIS06
    [
    let current-tree (?1)
    ;output-print current-tree
    let xy gis:location-of gis:centroid-of current-tree
    ;output-print xy
    let x item 0 xy
    let y item 1 xy
    create-GISmodel-trees 1
      [
      setxy x y
      set height gis:property-value current-tree "HIGHT53"
      set age gis:property-value current-tree "AGE"
      ifelse height >= 7
        [
        ;set color green
        ;set size 6
        hide-turtle
        set seed-tree? true
        ]
        [
        ;set color green
        ;set size 2
        hide-turtle
        set seed-tree? false
        ]
      ]
    ]
end


; load reduced fecundity scenario
to load-red-fec

  set trees-GIS06 gis:load-dataset "/TREELIM data/redfec.shp"
  set seeds-per-tree round (seeds-per-tree / 5.6)

  ;create tree 2006 agentset from GIS point data
  ;set-default-shape real-trees "circle"

  foreach gis:feature-list-of trees-GIS06
    [
    let current-tree (?1)
    ;output-print current-tree
    let xy gis:location-of gis:centroid-of current-tree
    ;output-print xy
    let x item 0 xy
    let y item 1 xy
    create-GISmodel-trees 1
      [
      setxy x y
      set height gis:property-value current-tree "HIGHT53"
      set age gis:property-value current-tree "AGE"
      ifelse height >= 7
        [
        ;set color green
        ;set size 6
        hide-turtle
        set seed-tree? true
        ]
        [
        ;set color green
        ;set size 2
        hide-turtle
        set seed-tree? false
        ]
      ]
    ]
end


; load short distance dispersal scenario
to load-short-dist

  set trees-GIS06 gis:load-dataset "/TREELIM data/shortdist.shp"
  set long-dispersal-dist 15

  ;create tree 2006 agentset from GIS point data
  ;set-default-shape real-trees "circle"

  foreach gis:feature-list-of trees-GIS06
    [
    let current-tree (?1)
    ;output-print current-tree
    let xy gis:location-of gis:centroid-of current-tree
    ;output-print xy
    let x item 0 xy
    let y item 1 xy
    create-GISmodel-trees 1
      [
      setxy x y
      set height gis:property-value current-tree "HIGHT53"
      set age gis:property-value current-tree "AGE"
      ifelse height >= 7
        [
        ;set color green
        ;set size 6
        hide-turtle
        set seed-tree? true
        ]
        [
        ;set color green
        ;set size 2
        hide-turtle
        set seed-tree? false
        ]
      ]
    ]
end



to go

  ask trees [disperse-seeds]
  ; if ticks >= 15 [stop]
  step

end


; run simulation for 52 years
to go-52years

  export
  ask trees [disperse-seeds]

  ; run 49 years (7 mast-year periods)
  repeat 7 [step]

  ; run the last 3 years
  set year year + 3
  set mast-period 3
  ask trees [update-trees]
  ask trees [compete]
  ask trees [trees-die]

  ; store .shp file
  ;let trees-sim gis:turtle-dataset trees
  ;gis:store-dataset trees-sim "E:/Gudrun/Modellierung/netlogo/trees_sim.shp"

  export
  output-print "fertig"

end


; Scheduler: run simulation for one step (= 8 years)
to step
  tick
  set year (year + mast-period)

  ; tree-related procedures each time step
  ask trees [update-trees]    ; get older, grow, update seed tree?, crown-radius, ZOI, set FON 0, inflection point i
  ask trees [compete]         ; calculate FON (high competition stress =  high FON)
  ask trees [trees-die]       ; trees die because of competition (FON > 0.5) or age (AGE > 250) or randomly (1% mortality rate per year)
  ask trees [disperse-seeds]  ; disperse seeds: germination (= future establishment) depends on lulc and elevation; FON = 0 (no seedling dies due to competition)


  ; succession: each tree contributes to the succession of the ground vegetation towards forest
  if succession = true
    [
    ask trees [drive-succession] ; the succession stage (a patch variable) below tree crowns gradually changes each time step
    ]

  ;output

end



; update seed-tree?, crown-radius, ZOI, reset FON
to update-trees

  set age age + mast-period

  ; calculate new height after 8 years
  grow mast-period

  ; update if trees are seed trees
  ifelse height >= 7
    [
    set seed-tree? true
    set size 6
    ]
    [
    set seed-tree? false
    set size 2
    ]

  ; calculate crown radius
  set crown-radius height ^ 0.55 / 2

  ; calculate the radius of competition influence; starting assumption: ZOI equals the crown radius x 2
  set ZOI crown-radius * 2

  ; reset field of neighbourhood (= competition strength) to 0
  set FON 0

  ; climate change: increases elevation dependent germination rate
  set i (i + climate-change * 0.7 * mast-period) ; how many meters inflection point shifts upwards every time step with given climate change rate and 0.7�C temperature decrease every 100m elevation

end



; assymtric competition: if 2 trees intersect, FON of smaller tree grows
to compete

  let ZOI-mine ZOI
  let height-mine height

  ask trees in-radius (ZOI-mine + 7.2)
    [
    let ZOI-neighbour ZOI
    let height-neighbour height

    ; if we overlap and I'm taller than my neighbour, the neighbour's FON increases
    if distance myself < (ZOI-mine + ZOI-neighbour) and height-mine > height-neighbour
      [
      let overlap (ZOI-mine + ZOI-neighbour - distance myself)
      if overlap > (ZOI-neighbour * 2)
          [
          set overlap (ZOI-neighbour * 2)
          ]

      ; the competition factor FON depends 60% on the amount of overlap and 40% on the height ratio
      set FON (FON + 0.6 * (overlap / (ZOI-neighbour * 2)) + 0.4 * (1 - (height-neighbour / height-mine )))
      ]
    ]

end




to disperse-seeds

  ; if a tree is a seed tree, it produces and disperses seeds
  if seed-tree? = true
    ; produce seeds that establish as saplings the next time step without competition this time step
    [
    hatch-trees seeds-per-tree
      [
      let seedX xcor
      let seedY ycor
      let ran-bear random 360
      lt ran-bear



      ; call procedure to identify random-gaussian distance a seedling is distributed and update the global variable "gaussian-dist"
      random-gaussian-dist

      ; check if seed falls beyond the end of the world
      ifelse can-move? gaussian-dist

        ; if seed is within world: go random-gaussian distance
        [
        fd gaussian-dist
        ]

        ; if not: bounce at the end of the world, set max to 200m to the left
        [
        fd gaussian-dist
        let rest-dist (gaussian-dist - distancexy seedX seedY)
        lt ran-bear - 180
        ;set ycor ycor - random 200
        fd rest-dist
        ]

       ; set initial tree variables for seeds
      set age 0
      set FON 0
      set height (0.08 + random-float 0.04)
      set species [species] of myself ; myself refers to the turtle that asked me to do what I'm doing now (tested, it works)
      if species = "spruce"
        [
        set color magenta
        set i 1550
        ]
      if species = "larch"
        [
        set color orange
        set i 1850
        ]
      set size 2

      ; germination (= mortality of seeds) in respect to land use (for land-use forest: 100% survival)
      let ran1 random-float 1
      if [ran1 > succession-stage] of patch-here [die]

      ; germination in respect to elevation
      let elev-tree [elev] of patch-here
      let const 155 ; constant
      let elev-prob 1 - ( 1 / (1 + e ^ (-((elev-tree - i) / const))))  ; empirical data (Tasser et al )
      set ran1 random-float 1
      if ran1 > elev-prob [die]

      ; set initial tree variables: seed-tree?, crown-radius, ZOI, set FON to 0
      update-trees
    ]
  ]

end




; calculate and report a gaussian-random distance
to random-gaussian-dist

  let ran-dist random-float 1000 + 0.2 ; assumption: maximum possible distribution is 1 km, minimum distance to tree point is 20 cm (stem radius)

  ; 2 combined gaussian distributions with a short (15m) and a long (110m) distance component
  let gaussian-dist-prob 0.5 * e ^ (-0.5 * (ran-dist / short-dispersal-dist) ^ 2) + 0.5 * e ^ (-0.5 * (ran-dist / long-dispersal-dist) ^ 2)  ; dispersal kernel after Clark et al 1999
  let ran3 random-float 1

  ifelse gaussian-dist-prob > ran3
    [
    set gaussian-dist ran-dist ; update the global "gaussian distance" variable
    ]
    [
    random-gaussian-dist ; else restart the procedure
    ]

end




to trees-die

  ; if a tree reaches the maximum age (250 years), it dies
  if age > 250 [die]

  ; random mortality of 1% each year sums up to 93.21% each 7th year
  if random-float 1 > 0.99 ^ mast-period [die]

  ; if competition is too high
  if species = "spruce"
    [if FON > comp-threshold [die] ]
  if species = "larch"
    [if FON > (comp-threshold / 5) [die] ]

end



; trees grow a given number of years
to grow [times]

  ; calculate height
  if [elev < 1600] of patch-here
    [
    repeat times
      [set height height-max * (( 1 - ( 1 - (( height / height-max) ^ ( 1 / 3 ))) * e ^ (- random-normal 0.031 0.003)) ^ 3)] ; Rammig nach Bertalanffy
    ]

  if [elev  >= 1600] of patch-here and [elev < 1800] of patch-here
    [
    repeat times
      [set height height-max * (( 1 - ( 1 - (( height / height-max) ^ ( 1 / 3 ))) * e ^ (- random-normal 0.03 0.003)) ^ 3)]
    ]

  if [elev  >= 1800] of patch-here and [elev < 1900] of patch-here
    [
    repeat times
      [set height height-max * (( 1 - ( 1 - (( height / height-max) ^ ( 1 / 3 ))) * e ^ (- random-normal 0.029 0.003)) ^ 3)]
    ]

  if [elev  >= 1900] of patch-here and [elev < 2100] of patch-here
    [
    repeat times
      [set height height-max * (( 1 - ( 1 - (( height / height-max) ^ ( 1 / 3 ))) * e ^ (- random-normal 0.028 0.003)) ^ 3)]
    ]

  if [elev >= 2100] of patch-here
    [
    repeat times
      [set height height-max * (( 1 - ( 1 - (( height / height-max) ^ ( 1 / 3 ))) * e ^ (- random-normal 0.027 0.003)) ^ 3)]
    ]

end


; succession under trees
to drive-succession

  ask patches in-radius (2 * crown-radius)
    [
    if (lulc = "ex-pasture") or (lulc = "shrubs")
      [
      set succession-stage (succession-stage + 0.02 * mast-period)
      if (succession-stage >= 1)
        [
        ;set lulc "forest"
        ;set pcolor 56 ; dark green
        ]
      ]
    ]

end



to output

  if print-plots = true
    [

      ; plot tree density along elevation gradient
      set-current-plot "tree dens over elev gradient"
      plot-pen-up
      let elev-here 1600
      repeat 19
        [
        let area count patches with [elev > elev-here and elev <= (elev-here + 50)]
        let number-of-spruce count trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4 and species = "spruce"]
        let spruce-dens number-of-spruce / area * 10000

        set-plot-pen-color magenta
        plotxy spruce-dens elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]

      set-current-plot "tree dens over elev gradient"
      plot-pen-up
      set elev-here 1600
      repeat 19
        [
        let area count patches with [elev > elev-here and elev <= (elev-here + 50)]
        let number-of-trees count trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4]
        let t-dens number-of-trees / area * 10000

        set-plot-pen-color black
        plotxy t-dens elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]

      set-current-plot "tree dens over elev gradient"
      plot-pen-up
      set elev-here 1600
      repeat 19
        [
        let area count patches with [elev > elev-here and elev <= (elev-here + 50)]
        let number-of-larch count trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4 and species = "larch"]
        let larch-dens number-of-larch / area * 10000

        set-plot-pen-color orange
        plotxy larch-dens elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]

      set-current-plot "tree dens over elev gradient in abandoned pastures"
      set-plot-pen-color black
      plot-pen-up
      set elev-here 1600 + tree-line
      repeat 19
        [
        let area2 count patches with [elev > elev-here and elev <= (elev-here + 50) and lulc = "ex-pasture"]
        let number-of-trees2 count trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4 and lulc = "ex-pasture"]
        let t-dens2 0
        if area2 != 0
        [set t-dens2 number-of-trees2 / area2 * 10000]

        plotxy t-dens2 elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]


      if ticks = 0
      [
      set-current-plot "tree dens over elev gradient"
      set-plot-pen-color blue
      plot-pen-up
      set elev-here 1600
      repeat 19
        [
        let area count patches with [elev > elev-here and elev <= (elev-here + 50)]
        let number-of-real-trees count real-trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4]
        let t-dens-real number-of-real-trees / area * 10000

        plotxy t-dens-real elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]

      set-current-plot "tree dens over elev gradient"
      set-plot-pen-color green
      plot-pen-up
      set elev-here 1600
      repeat 19
        [
        let area count patches with [elev > elev-here and elev <= (elev-here + 50)]
        let number-of-GISmodel-trees count GISmodel-trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4]
        let t-dens-GISmodel number-of-GISmodel-trees / area * 10000

        plotxy t-dens-GISmodel elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]


      set-current-plot "tree dens over elev gradient in abandoned pastures"
      set-plot-pen-color blue
      plot-pen-up
      set elev-here 1600 + tree-line
      repeat 19
        [
        let area2 count patches with [elev > elev-here and elev <= (elev-here + 50) and lulc = "ex-pasture"]
        let number-of-real-trees2 count real-trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4 and lulc = "ex-pasture"]
        ;let t-dens2 number-of-real-trees2 / area2 * 10000
        let t-dens2 0
        if area2 != 0
        [set t-dens2 number-of-real-trees2 / area2 * 10000]

        set-current-plot "tree dens over elev gradient in abandoned pastures"
        set-plot-pen-color blue
        plotxy t-dens2 elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]


      set-current-plot "tree dens over elev gradient in abandoned pastures"
      set-plot-pen-color green
      plot-pen-up
      set elev-here 1600 + tree-line
      repeat 19
        [
        let area2 count patches with [elev > elev-here and elev <= (elev-here + 50) and lulc = "ex-pasture"]
        let number-of-GISmodel-trees2 count GISmodel-trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4 and lulc = "ex-pasture"]
        let t-dens-GISmodel2 0
        if area2 != 0
        [set t-dens-GISmodel2 number-of-GISmodel-trees2 / area2 * 10000]

        plotxy t-dens-GISmodel2 elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]

      ]

      ]
end


to export


      if ticks = 0
      [
      set-current-plot "tree dens over elev gradient"
      set-plot-pen-color blue
      plot-pen-up
      let elev-here 1600
      repeat 19
        [
        let area count patches with [elev > elev-here and elev <= (elev-here + 50)]
        let number-of-real-trees count real-trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4]
        let t-dens-real number-of-real-trees / area * 10000

        plotxy t-dens-real elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]

      set-current-plot "tree dens over elev gradient"
      set-plot-pen-color green
      plot-pen-up
      set elev-here 1600
      repeat 19
        [
        let area count patches with [elev > elev-here and elev <= (elev-here + 50)]
        let number-of-GISmodel-trees count GISmodel-trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4]
        let t-dens-GISmodel number-of-GISmodel-trees / area * 10000

        plotxy t-dens-GISmodel elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]


      set-current-plot "tree dens over elev gradient in abandoned pastures"
      set-plot-pen-color blue
      plot-pen-up
      set elev-here 1600 + tree-line
      repeat 19
        [
        let area2 count patches with [elev > elev-here and elev <= (elev-here + 50) and lulc = "ex-pasture"]
        let t-dens2 0
        if area2 != 0
        [
        let number-of-real-trees2 count real-trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4 and lulc = "ex-pasture"]
        set t-dens2 number-of-real-trees2 / area2 * 10000
        ]

        plotxy t-dens2 elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]


      set-current-plot "tree dens over elev gradient in abandoned pastures"
      set-plot-pen-color green
      plot-pen-up
      set elev-here 1600 + tree-line
      repeat 19
        [
        let area2 count patches with [elev > elev-here and elev <= (elev-here + 50) and lulc = "ex-pasture"]
        let t-dens-GISmodel2 0
        if area2 != 0
        [
        let number-of-GISmodel-trees2 count GISmodel-trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4 and lulc = "ex-pasture"]
        set t-dens-GISmodel2 number-of-GISmodel-trees2 / area2 * 10000
        ]

        plotxy t-dens-GISmodel2 elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]

      set-current-plot "tree dens over elev gradient"
      plot-pen-up
      set elev-here 1600
      repeat 19
        [
        let area count patches with [elev > elev-here and elev <= (elev-here + 50)]
        let number-of-trees count trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4]
        let t-dens number-of-trees / area * 10000

        set-plot-pen-color blue
        plotxy t-dens elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]


      set-current-plot "tree dens over elev gradient in abandoned pastures"
      plot-pen-up
      set elev-here 1600 + tree-line
      repeat 19
        [
        let area2 count patches with [elev > elev-here and elev <= (elev-here + 50) and lulc = "ex-pasture"]
        let t-dens2 0
        if area2 != 0
        [
        let number-of-trees2 count trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4 and lulc = "ex-pasture"]
        set t-dens2 number-of-trees2 / area2 * 10000
        ]

        set-plot-pen-color blue
        plotxy t-dens2 elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]

      ]

      if year = 2006
      [
      set-current-plot "tree dens over elev gradient"
      plot-pen-up
      let elev-here 1600
      repeat 19
        [
        let area count patches with [elev > elev-here and elev <= (elev-here + 50)]
        let number-of-trees count trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4]
        let t-dens number-of-trees / area * 10000

        set-plot-pen-color black
        plotxy t-dens elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]


      set-current-plot "tree dens over elev gradient in abandoned pastures"
      plot-pen-up
      set elev-here 1600 + tree-line
      repeat 19
        [
        let area2 count patches with [elev > elev-here and elev <= (elev-here + 50) and lulc = "ex-pasture"]
        let t-dens2 0
        if area2 != 0
        [
        let number-of-trees2 count trees with [elev > elev-here and elev <= (elev-here + 50) and height >= 4 and lulc = "ex-pasture"]
        set t-dens2 number-of-trees2 / area2 * 10000
        ]

        set-plot-pen-color black
        plotxy t-dens2 elev-here

        plot-pen-down
        set elev-here elev-here + 50
        ]
      ]
end

;; by Gudrun Wallentin
;; Wallentin, G., Tappeiner, U., Strobl, J., Tasser, E. 2008. Alpine tree line dynamics: an individual based model. Ecological Modelling 218(3-4), 235-246.
;; Licenced under cc-by (open to use, share, redistribute, modify - please cite using the above reference)
@#$#@#$#@
GRAPHICS-WINDOW
17
10
1680
695
-1
-1
1.0
1
12
1
1
1
0
0
1
1
0
1652
0
653
1
1
1
ticks
30.0

BUTTON
19
607
82
640
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
105
607
168
640
NIL
step
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
186
382
328
415
print-plots
print-plots
0
1
-1000

MONITOR
869
437
941
482
seed trees
count trees with [height >= 7]
17
1
11

MONITOR
867
486
944
531
NIL
count trees
17
1
11

MONITOR
865
337
923
382
year
year
17
1
11

BUTTON
19
377
135
410
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
17
511
167
556
visible-layer
visible-layer
"DEM" "lulc" "black"
1

BUTTON
16
559
167
592
display selected layer
choose-layer
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
336
379
599
682
tree dens over elev gradient
NIL
NIL
0.0
110.0
1600.0
2300.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

BUTTON
19
647
116
680
go 52 years
go-52years
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
481
417
597
501
black: all trees\nmagenta: spruce\nyellow: larch\n\nreal: blue\nGIS-model: green
11
0.0
1

SWITCH
862
64
1021
97
succession
succession
1
1
-1000

SLIDER
863
105
1022
138
climate-change
climate-change
0
5
0
0.5
1
NIL
HORIZONTAL

CHOOSER
16
461
177
506
scenario
scenario
"baseline" "reduced fecundity" "reduced competition" "short distribution"
3

PLOT
603
379
850
681
tree dens over elev gradient in abandoned pastures
NIL
NIL
0.0
110.0
1600.0
2300.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

TEXTBOX
741
412
835
496
black: all trees\n\nreal: blue\nGIS-model: green
11
0.0
1

MONITOR
866
539
1042
584
forest: dens sim / dens real
count trees with [lulc = \"forest\" and height >= 4] / count real-trees with [lulc = \"forest\" and height >= 4]
3
1
11

MONITOR
865
586
1041
631
shrubs: dens sim / dens real
count trees with [lulc = \"shrubs\" and height >= 4] / count real-trees with [lulc = \"shrubs\" and height >= 4]
3
1
11

MONITOR
866
635
1041
680
abandoned: dens sim / dens real
count trees with [lulc = \"ex-pasture\" and height >= 4] / count real-trees with [lulc = \"ex-pasture\" and height >= 4]
3
1
11

MONITOR
948
436
1037
481
seed trees real
count real-trees with [height >= 7]
17
1
11

MONITOR
949
485
1037
530
NIL
count real-trees
17
1
11

MONITOR
1042
437
1155
482
seed trees GIS-model
count GISmodel-trees with [height >= 7]
17
1
11

MONITOR
1042
484
1155
529
NIL
count GISmodel-trees
17
1
11

MONITOR
1046
538
1213
583
forest: dens sim / dens GISmodel
count trees with [lulc = \"forest\" and height >= 4] / count GISmodel-trees with [lulc = \"forest\" and height >= 4]
3
1
11

MONITOR
1046
586
1214
631
shrubs: dens sim / dens GISmodel
count trees with [lulc = \"shrubs\" and height >= 4] / count GISmodel-trees with [lulc = \"shrubs\" and height >= 4]
3
1
11

MONITOR
1043
633
1214
678
abandoned: dens sim / dens GISmodel
count trees with [lulc = \"ex-pasture\" and height >= 4] / count GISmodel-trees with [lulc = \"ex-pasture\" and height >= 4]
3
1
11

MONITOR
867
385
968
430
fraction of larch
count trees with [species = \"larch\"] / count trees
3
1
11

CHOOSER
862
11
1022
56
species-chooser
species-chooser
"spruce only" "10% larch" "larch above 1880m"
1

TEXTBOX
1044
281
1246
422
to compare with GIS model\nhatch 10, 12 (15) 18\nFON 0.75, 0.9 (0.75) 0.6\n\nforest: 0.789, 0.976 (0.943) 0.892\nshrubs: 0.967, 0.933 (1.033) 1.433\nabandoned: 1.029, 1.257 (1.606) 1.554\ntrees: 7198, 9647 (10858) 11312\nseed trees 2627, 3134 (3165) 2942
11
0.0
1

CHOOSER
16
414
165
459
landscape
landscape
"Breitlehn" "artificial"
1

@#$#@#$#@
## FOREST DYNAMICS AT THE ALPINE TREE LINE

The model description follows the ODD protocol for describing individual- and agent-based models (Grimm et al. 2006; Grimm and Railsback 2005).

## PURPOSE

The model simulates the spatial patterns of secondary forest succession above the current alpine tree line in the context of land use and climate change. In particular we are interested in showing the relative importance of:
(1) climate change, (2) land use change, (3) initial species composition

## STATE VARIABLES AND SCALES

The models� entities are points, representing individual trees of Norway spruce and European larch in a grid with a resolution of 10 x 10m, representing a virtual landscape of 150ha (150m x 1000m) between 1500m and 2500m a.s.l..
The model simulates the forest establishment above the current tree-line in time steps of masting years.

Global variables
	* year
	* mast-period ; 7 years

Tree attributes
	* species ; spruce or larch
	* age ; age of trees in years
	* height ; tree height in m
	* seed-tree? ;  boolean, is tree mature, i.e. able to produce seeds?
	* crown-radius
	* ZOI ; radius of the max. competition influence radius, depending on tree age
	* FON ; sum of assymetric competition influence of neighbouring trees on a tree
	* i ; inflection point

Cell attributes
	* elevation
	* land use / land cover (lulc) at the beginning of the simulation (forest,
	  pasture and recently abandoned pasture)
	* tree density

## PROCESS OVERVIEW

At its initial stage, the model represents a tree-line ecotone with a dense forest below, and pastures or recently abandoned pastures above a sharp tree line. At the beginning of each simulation, the user is asked to set the amount and the spatial distribution of abandoned land. In a simulation run, seed trees produce and disperse seeds. Forest succession patterns emerge from landscape hetereogeneity (lulc and elevation determine germination-rates) and tree competition (tree mortality is driven by age and density).


## SCHEDULE

1) tick
	* advance one time step
2) set year
	* year of last time step + mast-period (7 years)
3) Update trees' variables:
	* get older
	* grow
	* check if mature
	* crown-radius
	* ZOI (=area of competition influence around a tree)
	* set FON (=competition stress factor) 0
	* inflection point (=climate change induced germination probability factor) i
4) Compete
	* calculate FON (high competition stress =  high FON)
5) Mortality
	* trees die because of competition (FON > 0.5) or age (AGE > 250) or randomly
	(1% mortality rate per year)
6) Dispersal
	* disperse seeds of future saplings (only seeds that have successfully
	  established are considered);
	* germination (= future establishment) depends on lulc and elevation;
	* FON = 0 (no seedling dies due to competition)
7) Succession
	* the succession stage (a patch variable) below tree crowns gradually changes
	* each time step
8) Report output variables
	* tree density
	* fraction of larch trees
	* number of seed trees

each process is executed for all entities before the next process starts

## DESIGN CONCEPTS

Emergence
The quantity and spatial distribution of trees above the tree line after abandonment of alpine pastures.

Sensing
Trees are assumed to sense trees in their neighbourhood (ZOI).

Interaction
Tree competition for resources is modelled indirectly through tree denisity.

Stochasticity
Seed dispersal follows a gaussian kernel.
The initialial distribution of abandoned pasture is random, within the user-defined lulc fraction and distance variables.

Observation
Two state variables describing tree establishment above the tree line are reported:
	* number of trees above the forest edge
	* mean distance of trees to the forest edge.

## INITIALISATION

Breitlehn study area
import lulc, DEM and trees from GIS data files

artificial landscape
1. Set topography and land use:
a) The tree-line is at 1650m, the area below is initialised as dense forest

b) Above 1650m, the spatial distribution of lulc is user-defined. It can be:

* random (randomely distributed cells of pasture and abandoned pasture)
The user can chose the fraction of abandoned pasture.

* not-random (one or more circular clusters of abandoned pasture within the pasture with a defined distance to the forest)
The user can chose the amount of clusters, the cluster radius and the distance to the forest

2. Create trees in the forest at random positions with a normal random age distribution around 60 years. The number of trees per forest cell equals the maximum age dependent tree density.

## SUBMODELS
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="results-random-dist" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <exitCondition>ticks = 10</exitCondition>
    <metric>count trees with [ycor &gt; tree-line]</metric>
    <metric>mean [fo-dist] of trees with [ycor &gt; tree-line]</metric>
    <enumeratedValueSet variable="print-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cluster-radius">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-use-distribution">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ex-pasture-clusters">
      <value value="1"/>
    </enumeratedValueSet>
    <steppedValueSet variable="abandoned-pasture-fraction" first="0" step="10" last="100"/>
  </experiment>
  <experiment name="results-clustered-dist" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <exitCondition>ticks = 10</exitCondition>
    <metric>count trees with [ycor &gt; tree-line]</metric>
    <metric>mean [fo-dist] of trees with [ycor &gt; tree-line]</metric>
    <enumeratedValueSet variable="print-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cluster-radius">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="land-use-distribution">
      <value value="&quot;clustered&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ex-pasture-clusters">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="abandoned-pasture-fraction">
      <value value="50"/>
    </enumeratedValueSet>
    <steppedValueSet variable="cluster-dist" first="5" step="5" last="50"/>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
